SimplifiedTreeNode

Enum SimplifiedTreeNode 

pub enum SimplifiedTreeNode {
    Empty,
    Symbol(Atom),
    Union(Vec<SimplifiedTreeNode>),
    Capture(Box<SimplifiedTreeNode>, usize),
    Concat(Vec<SimplifiedTreeNode>),
    Repeat(Box<SimplifiedTreeNode>, NonZero<usize>),
    UpTo(Box<SimplifiedTreeNode>, NonZero<usize>, bool),
    Star(Box<SimplifiedTreeNode>, bool),
    Start,
    End,
    Never,
}
For translation between our parsed ERE and the crate::working_nfa::WorkingNFA

Variants



Empty

Translates to epsilon



Symbol(Atom)



Union(Vec<SimplifiedTreeNode>)



Capture(Box<SimplifiedTreeNode>, usize)

Capture(child, group_num)



Concat(Vec<SimplifiedTreeNode>)



Repeat(Box<SimplifiedTreeNode>, NonZero<usize>)

Repeat(child, times)



UpTo(Box<SimplifiedTreeNode>, NonZero<usize>, bool)

UpTo(child, max_times, longest)



Star(Box<SimplifiedTreeNode>, bool)

Star(child, longest)



Start



End



Never

Implementations

Source

impl SimplifiedTreeNode

pub fn optional(self, longest: bool) -> SimplifiedTreeNode

pub fn union(self, other: SimplifiedTreeNode) -> SimplifiedTreeNode

pub fn capture(self, group_num: usize) -> SimplifiedTreeNode

pub fn concat(self, other: SimplifiedTreeNode) -> SimplifiedTreeNode

pub fn repeat(self, count: usize) -> SimplifiedTreeNode

pub fn upto(self, count: usize, longest: bool) -> SimplifiedTreeNode

pub fn star(self, longest: bool) -> SimplifiedTreeNode

pub fn max_bytes(&self) -> Option<usize>

An upper bound for matched text length, in bytes. If possibly infinite, returns None.

pub fn min_bytes(&self) -> usize

A lower bound for matched text length, in bytes.

Source

impl SimplifiedTreeNode

pub fn from_ere(value: &ERE, config: &Config) -> (SimplifiedTreeNode, usize)

Returns the simplified tree, along with the number of capture groups (full expression is group 0)